==> maxdb-source-7_6_00_09.tgz: V76_00_09/MaxDB_ORG/sys/src/SAPDB/DBM/Srv/Commands/Scheduler/DBMSrvCmdScd_SchedulerDeleteJob.cpp <==
/*!
  \file    DBMSrvCmdScd_SchedulerDeleteJob.cpp
  \author  MarcW
  \ingroup DBMServer commands
  \brief   delete a job

\if EMIT_LICENCE

    ========== licence begin  GPL
    Copyright (C) 2002-2004 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

\endif
*/

#include "DBM/Srv/Commands/Scheduler/DBMSrvCmdScd_SchedulerDeleteJob.hpp"
#include "DBM/Srv/Commands/Scheduler/DBMSrvCmdScd_SchedulerState.hpp"
#include "DBM/Srv/SharedMemory/DBMSrvShM_LineAccessorScheduler.hpp"

DBMSrvCmdScd_SchedulerDeleteJob::DBMSrvCmdScd_SchedulerDeleteJob()
: DBMSrvCmdScd_SchedulerCommand( DBMSrv_Command::KeySchedulerDeleteJob)
{
    m_longHelp=
        "@command scheduler_delete_job This command deletes a scheduled job. It is removed from "
        "the scheduler's job list. This command can be executed no matter whether the scheduler "
        "is running or not."
        "@preconditions The job has no successors. You have the DBM operator authorization "
            "SchedulerMgm or you are the job's owner and have the DBM operator authorization "
            "Scheduling."
        "@syntax scheduler_delete_job <job_id>"
        "@param <job_id> Id of job to be deleted."
        "@reply OK";
}

tcn00_Error DBMSrvCmdScd_SchedulerDeleteJob::runLockProtected(
    VControlDataT* vcontrol,
    CommandT* command,
    DBMSrvCmdScd_SchedulerReply& theSchedReply) {

    theSchedReply.startWithOK();

    // check whether we got a numeric parameter
    if( !isNumeric(command->oArguments.getValue(1)) ) {
        Msg_List illegalJobNumber(
            DBMSrv_DBMError(ILLJOBNUMBER), 1 , command->oArguments.getValue(1).CharPtr());
        return theSchedReply.startWithMessageList(illegalJobNumber);
    }

    // now send request to scheduler
    DBMSrvShM_LineAccessorScheduler laSch;
    laSch.setInfoType(DBMSrvShM_LineAccessorScheduler::IT_DeleteJob);
    laSch.setVariablePart(command->oArguments.getValue(1).CharPtr());
    laSch.setUserName(getUser());
    laSch.setRecipientScheduler();

    // start the scheduler if it's not running yet
    DBMSrvCmdScd_SchedulerState cmdGetState;
    bool schedulerUpInitialy(cmdGetState.isSchedulerUp());
    if( !schedulerUpInitialy ) {
        tcn00_Error theRC = startScheduler(theSchedReply);
        if( theRC != OK_CN00 )
            return theRC;
    }

    // wait for answer from scheduler
    laSch.clientWait();

    // now there should be an answer
    DBMSrvShM_LineAccessorScheduler::InfoType infTy;
    char* pVarPart(NULL);
    laSch.getInfoType(infTy);
    laSch.getVariablePart(pVarPart);

    theSchedReply.appendSchedulerInfo(infTy, pVarPart);

    delete pVarPart;

    // we processed what came back, now clear shm line
    laSch.clearContent();

    // stop scheduler if it was not up initially
    if( !schedulerUpInitialy )
        return stopScheduler(theSchedReply);
    else
        return OK_CN00;
}

==> maxdb-source-7_6_00_27.tgz: V76_00_27/MaxDB_ORG/sys/src/SAPDB/DBM/Srv/Commands/Scheduler/DBMSrvCmdScd_SchedulerDeleteJob.cpp <==
/*!
  \file    DBMSrvCmdScd_SchedulerDeleteJob.cpp
  \author  MarcW
  \ingroup DBMServer commands
  \brief   delete a job

    ========== licence begin  GPL
    Copyright (c) 2002-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*/

#include "DBM/Srv/Commands/Scheduler/DBMSrvCmdScd_SchedulerDeleteJob.hpp"
#include "DBM/Srv/Commands/Scheduler/DBMSrvCmdScd_SchedulerState.hpp"
#include "DBM/Srv/SharedMemory/DBMSrvShM_LineAccessorScheduler.hpp"
#include "DBM/Srv/Message/DBMSrvMsg_Error.hpp"

DBMSrvCmdScd_SchedulerDeleteJob::DBMSrvCmdScd_SchedulerDeleteJob()
: DBMSrvCmdScd_SchedulerCommand( DBMSrv_Command::KeySchedulerDeleteJob)
{
    m_longHelp=
        "@command scheduler_delete_job This command deletes a scheduled job. It is removed from "
        "the scheduler's job list. This command can be executed no matter whether the scheduler "
        "is running or not."
        "@preconditions The job has no successors. You have the DBM operator authorization "
            "SchedulerMgm or you are the job's owner and have the DBM operator authorization "
            "Scheduling."
        "@syntax scheduler_delete_job <job_id>"
        "@param <job_id> Id of job to be deleted."
        "@reply OK";
}

tcn00_Error DBMSrvCmdScd_SchedulerDeleteJob::runLockProtected(
    VControlDataT* vcontrol,
    CommandT* command,
    DBMSrvCmdScd_SchedulerReply& theSchedReply) {

    DBMSrvMsg_Error errOut;
    theSchedReply.startWithOK();

    // check whether we got a numeric parameter
    if( !isNumeric(command->oArguments.getValue(1)) ) {
        return theSchedReply.startWithMessageList(DBMSrvMsg_Error(SDBMSG_DBMSRV_ILLJOBNUMBER, Msg_Arg(SDBMSGTAG_DBMSRV_ILLJOBNUMBER__DBMSRV_COMP,command->oArguments.getValue(1).CharPtr())));
    }

    // now send request to scheduler
    DBMSrvShM_LineAccessorScheduler laSch(errOut);
    if( !errOut.IsEmpty() )
        return theSchedReply.startWithMessageList(errOut);

    if( !(laSch.setInfoType(DBMSrvShM_LineAccessorScheduler::IT_DeleteJob, errOut) &&
          laSch.setVariablePart(command->oArguments.getValue(1).CharPtr(), errOut) &&
          laSch.setUserName(getUser(), errOut) &&
          laSch.setRecipientScheduler(errOut)) )
        return theSchedReply.startWithMessageList(errOut);

    // start the scheduler if it's not running yet
    DBMSrvCmdScd_SchedulerState cmdGetState;
    bool schedulerUpInitialy(cmdGetState.isSchedulerUp(errOut));
    if( !errOut.IsEmpty() )
        return theSchedReply.startWithMessageList(errOut);

    if( !schedulerUpInitialy ) {
        tcn00_Error theRC = startScheduler(theSchedReply);
        if( theRC != OK_CN00 )
            return theRC;
    }

    // wait for answer from scheduler
    if( !laSch.clientWait(errOut) )
        return theSchedReply.startWithMessageList(errOut);

    // now there should be an answer
    DBMSrvShM_LineAccessorScheduler::InfoType infTy;
    char* pVarPart(NULL);
    if( !(laSch.getInfoType(infTy, errOut) && laSch.getVariablePart(pVarPart, errOut)) ) {
        if( pVarPart != NULL )
            delete pVarPart;
        return theSchedReply.startWithMessageList(errOut);
    }

    theSchedReply.appendSchedulerInfo(infTy, pVarPart);

    if( pVarPart != NULL )
        delete pVarPart;

    // we processed what came back, now clear shm line
    if( !laSch.clearContent(errOut) )
        return theSchedReply.startWithMessageList(errOut);

    // stop scheduler if it was not up initially
    if( !schedulerUpInitialy )
        return stopScheduler(theSchedReply);
    else
        return OK_CN00;
}
